@@ -1,4 +1,4 @@
-from .searchlite import google
+from .searchlite import google,duckduckgo,wikipedia
 from .parselite import parse
 from .visionlite import wlsplit,wlanswer,wltopk,wlsimchunks
 
@@ -13,6 +13,6 @@ from .project_to_prompt import project_to_prompt,project_to_markdown,ProjectToPr
 
 from .arxivlite import get_todays_arxiv_papers,research_paper_analysis
 
-from .deep_research import deep_research
+from .deep_research import DeepResearchSystem,deep_research_email
 
 from .utils.render_mermaid import render_mermaid,extract_mermaid
\ No newline at end of file
