@@ -178,5 +178,7 @@ class ProjectToPrompt:
         return markdown
 
 def project_to_prompt(path:str):
+    """takes path of directory/project and returns that in prompt format for llm like funcitonand classes names
+    params with docstrings level only not full code and return it as full prompt version of code base"""
     obj = ProjectToPrompt(path)
     return obj.generate_markdown()
\ No newline at end of file
