@@ -1,3 +1,6 @@
+"""
+using wordllama model we split text semantically, preform answering aka finding relevant chunk
+"""
 from typing import List, Tuple, Union
 
 from wordllama import WordLlama
